// AD7606Interface.h

#ifndef _AD7606INTERFACE_h
#define _AD7606INTERFACE_h

#include <Arduino.h>
#include <UrsSTM32F1-AD7606Spi.h>
#include "SerialControl.h"

// Schnittstelle zum AD7606 definieren
constexpr uint8_t rstPin = PA2;   // (RST) Pin fr den Reset
constexpr uint8_t cvaPin = PA3;   // (CVA) Pin startet die Messung (mit CVB verbunden)
constexpr uint8_t busyPin = PA1;  // (BUSY) Pin fr BUSY-Signal. 
                                  // Wenn ein anderer Pin benutzt wird, muss ein anderer EXTI-Interrupt berschrieben werden
constexpr uint8_t csPin = BOARD_SPI1_NSS_PIN; // = PA4 (CS) Pin fr CS-Signal.
// Clock & MISO werden ber die SPI-Schnittstelle definiert

constexpr int maxSampleCount = 200; // Max. Anzahl von Messungen in einem Messreihe
                                    // Max 800. Mehr gibt das RAM des SMT32F103 nicht her
constexpr int minTime = 8;          // Kleinste Taktzeit in uS. Bei kleineren Werten kommt das Timing durcheinander.
extern HardwareTimer sampleTimer;   // = HardwareTimer(1), in .cpp definiert
                                    // Wenn ein anderer Timer verwendet wird, muss ein anderer Interrupts berschrieben werden.



// Kontrolliert den Mesvorgang
class AD7606Control {
public:
   static void begin(SerialControl* sc);   // Schnittstelle initalisieren. SerialControl fr die Datenausgabe.
   static void setTime(uint microSeconds); // Messtakt einstellen
   static void setCount(uint sampleCount); // Anzahl Samples pro Messreihe festlegen
   static void reset();                    // Lst einen Reset des AD7606 aus, einschl. Dummyread.
   static void startSampling();            // Messreihe starten
   static bool hasFinished();              // true, wenn Messreihe abgeschlossen. 
                                           // Setzt gleichzeitig das Flag zurck.
   static void printReport();              // Ausgabe der Daten
};

#endif