
#include "AD7606Control.h"

// Schnittstelle zum AD7606
UrsAD7606bp<rstPin, cvaPin, busyPin, clockPin, ssPin, AD7606Range::Volt5> ursAD7606bs;

// Timer, der die Messungen innerhalb einer Messreihe taktet
HardwareTimer sampleTimer = HardwareTimer(1);


SerialControl* outDev; // Zur Ausgabe


// Messreihe definieren
int sampleCount = 10;                // Anzahl Messungen, die zu einer Messreihe gehren (< maxSampleCount)
AD7606DataSet samples[maxSampleCount]; // Puffer zur Aufnahme der Messwerte
volatile bool samplingDone = false;  // true, wenn eine Messreihe beendet wurde
volatile int currentSampleCount = 0; // Aktuell durchgefhrte Messungen


// Messreihe per Timer-Interrupt aufnehmen.
void timerInterruptHandler() {
   if (currentSampleCount >= sampleCount - 1) { // Alle Messungen wurden gestartet
      sampleTimer.c_dev()->regs.gen->CR1 &= ~TIMER_CR1_CEN;  //Timer abschalten [sampleTimer.pause();]

      while (ursAD7606bs.isBusy()); // Warten, bis letze Messung beendet
      ursAD7606bs.readData(&samples[currentSampleCount]); // letzten Wert auslesen
      samplingDone = true; // Messreihe komplett
      return;
   }

   // Weitere Messungen notwendig
   ursAD7606bs.startAndRead(&samples[currentSampleCount++]);
}


void AD7606Control::begin(SerialControl* sc) {
   outDev = sc;
   ursAD7606bs.begin();
   sampleTimer.init();
   setTime(10); // Taktzeit einstellen, Default ist 10us
   setCount(10); // Gre der Messreihe, Default ist 10 Samples pro Messreihe
   sampleTimer.attachInterrupt(0, timerInterruptHandler);
}

void AD7606Control::setTime(uint microSeconds) {
   if (microSeconds < minTime)
      microSeconds = minTime;
   sampleTimer.setPeriod(microSeconds);
   outDev->print("Timer set to "); outDev->print(microSeconds); outDev->println(" us.");

}

void AD7606Control::setCount(uint sc) {
   if (sc > maxSampleCount)
      sc = maxSampleCount;
   sampleCount = sc;
   outDev->print("Sample Count set to "); outDev->print(sampleCount); outDev->println(".");
}

void AD7606Control::reset() {
   ursAD7606bs.reset(AD7606DummyRead::enable);
   outDev->println("Reset done");
}

void AD7606Control::startSampling() {
   outDev->println("Start sampling");
   Serial.flush(); //bertragungabschlieen
   currentSampleCount = 0; // Neue Messreihe
   sampleTimer.resume();
   ursAD7606bs.start(); // Erste Messung starten, wird dann in der Timer-ISR eingelesen
}

bool AD7606Control::hasFinished() {
   bool temp = samplingDone;
   samplingDone = false;
   return temp;
}

void AD7606Control::printReport() {
   outDev->println("     Ch1      Ch2      Ch3      Ch4      Ch5      Ch6      Ch7      Ch8");
   for (int s = 0; s < sampleCount; s++) { // ber alle Messreihen
      // Messreihennummer ausgeben
      auto n = s + 1; 
      if (n < 10)outDev->print(" ");
      if (n < 100)outDev->print(" ");
      outDev->print(n); outDev->print(" ");
      
      for (int i = 0; i < 8; i++) { // ber alle Kanle
         auto d = ursAD7606bs.value(samples[s].channel[i]);
         if (d >= 0)
            outDev->print(" "); // Platz fr fehlendes Minus-Zeichen
         outDev->print(d, 4);
         outDev->print("  ");
      }
      outDev->println("");
   }
}

