// AD7606Interface.h

#ifndef _AD7606INTERFACE_h
#define _AD7606INTERFACE_h

#include <Arduino.h>
#include <UrsSTM32F1-AD7606bp.h>
#include "SerialControl.h"

// Schnittstelle zum AD7606 definieren
// Steuerleitungen mssen all auf Port B liegen!
constexpr uint8_t rstPin = PB11;   // (RST) Pin fr den Reset
constexpr uint8_t cvaPin = PB6;    // (CVA) Pin startet die Messung (mit CVB verbunden)
constexpr uint8_t busyPin = PB0;   // (BUSY) Pin fr BUSY-Signal
constexpr uint8_t clockPin = PB10; // (RD) Pin fr die Ausgabe des Taktsignals
constexpr uint8_t ssPin = PB1;     // (CS) Pin fr die Ausgabe des Chip-Select-Signals (Slave-Select)

constexpr int maxSampleCount = 200; // Max. Anzahl von Messungen in einem Messreihe
                                    // Max 800. Mehr gibt das RAM des SMT32F103 nicht her
constexpr int minTime = 6;          // Kleinste Taktzeit in uS. Bei kleineren Werten kommt das
                                    // Timing durcheinander

// Kontrolliert den Mesvorgang
class AD7606Control {
public:

   static void begin(SerialControl* sc);   // Schnittstelle initalisieren. SerialControl fr die Datenausgabe.
   static void setTime(uint microSeconds); // Messtakt einstellen
   static void setCount(uint sampleCount); // Anzahl Samples pro Messreihe festlegen
   static void reset();                    // Lst einen Reset des AD7606 aus, einschl. Dummyread.
   static void startSampling();            // Messreihe starten
   static bool hasFinished();              // true, wenn Messreihe abgeschlossen. 
                                           // Setzt gleichzeitig das Flag zurck.
   static void printReport();              // Ausgabe der Daten
};

#endif